@@ -7,36 +7,42 @@
 /***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#ifndef _CECAIAMANAGER_H_
-#define _CECAIAMANAGER_H_
+#ifndef CECAIAMANAGER_H
+#define CECAIAMANAGER_H
 
-#include <qobject.h>
 #include <qvaluevector.h>
-#include <qstringlist.h>
-#include <qstring.h>
 #include <qdatetime.h>
-#include <eca-control-interface.h>
 #include "ctrackinf.h"
-
-//! 󥸥󥹥ơ
-typedef int Status;
+#include "cecaiacontroller.h"
 
 /*-------------------------------------------------------------------------*/
 /*! \class  CEcaIAManager
-    \brief  Ecasound󥿥饯ƥ֥⡼ɤ椹뤿Υ饹
+    \brief  VoxStormΥ󥸥
 */
 /*-------------------------------------------------------------------------*/
-class CEcaIAManager : public QObject
+class CEcaIAManager : public CEcaIAController
 {
   Q_OBJECT
+
 public:
   enum RunningStatus {
     NotRunning,
@@ -48,7 +54,7 @@ public:
   //! \brief 󥹥ȥ饯
   CEcaIAManager();
   //! \brief ǥȥ饯
-  ~CEcaIAManager();
+  virtual ~CEcaIAManager();
 
   //! \brief  Ծ֤֤
   //! \return Ծ֡
@@ -57,9 +63,6 @@ public:
   //! \param  strTrackName ȥå̾Ρ
   //! \return ¸ߤƤ硢true֤
   bool isExisting(const QString& strTrackName) const;
-  //! \brief  󥻥åȥåפϲǽɤ֤
-  //! \return (ޤϿ)ǽʾ硢true֤
-  bool isValidChainsetup();
   //! \brief  ꤵƤϤο֤
   //! \return Ϥο
   int numberOfInputs();
@@ -82,8 +85,8 @@ public slots:
   //! \brief ߡ
   void slotPause();
   //! \brief ޥݥѹ롣
-  //! \param Time ְ֡
-  void slotSetMasterPosition(const QTime& Time);
+  //! \param time ְ֡
+  void slotSetMasterPosition(const QTime& time);
   //! \brief ֤ذư
   //! \param nSec ð֡
   void slotSetMasterPosition(int nSec);
@@ -146,8 +149,6 @@ private:
   //! \brief 黻ҡػߤ뤿ᡢprivate
   CEcaIAManager& operator=(const CEcaIAManager&);
 
-  //! Ecasound Control Interface
-  ECA_CONTROL_INTERFACE EcaControler;
   //! ȥå٥
   QValueVector<CTrackInf> vTrackChains;
   //! Ewfѥȥå٥
@@ -161,30 +162,11 @@ private:
   //! Ծ
   RunningStatus rStatus;
 
-  //! ֥륯
-  static const QString DQ;
-  //! 󥸥ξ֡¹档
-  static const Status Running;
-  //! 󥸥ξ֡¹Ԥ
-  static const Status NotStarted;
-  //! 󥸥ξ֡ߡ
-  static const Status Stopped;
-  //! 󥸥ξ֡¹Խλ
-  static const Status Finished;
-  //! 󥸥ξ֡ưԤ
-  static const Status NotReady;
-  //! 󥸥ξ֡顼
-  static const Status Error;
-
   //! \brief ȥå̾ΤФȥåΥǥ֤
   //! ꤵ줿ȥå̾ΤФȥå󤬸Ĥʤ硢
   //! -1֤롣
   //! \param strTrackName ȥå̾Ρ
   int getIndexByName(const QString& strTrackName) const;
-  //! \brief EcaControler˥ޥɤ롣
-  //! \param strCommand EIAMޥɡ
-  //! \param bOut ɸϤ˼¹ԤޥɤϤ硢trueꡣ
-  void command(const QString& strCommand, bool bOut=true);
   //! \brief ϥեȥǥХEcaControlerꤹ롣
   //! \param bRecord 쥳ǥ󥰤ͭˤʤäƤtrueꡣ
   //! \todo  too heavy
@@ -194,8 +176,6 @@ private:
   //! \param bWithPlaying ʤߥå󤹤trueꡣ
   //! \param strFileName ߥåե̾Ρ
   void setMixdownIOToCurrentChainsetup(bool bWithPlaying, const QString& strFileName);
-  //! \brief ߤξ֤֤
-  Status engineStatus();
   //! \brief ޥ٥ȡ
   //! Ecasoundκλ(Finished)Ƚꤹ뤿Υޥ٥ȡ
   void timerEvent(QTimerEvent* TimerEvent);
@@ -241,9 +221,6 @@ signals:
   //! \brief Ecasoundξ֤Finishedˤʤäȯ륷ʥ롣
   //! Stopped֤ˤʤäƤȯʤ
   void finished();
-  //! \brief å줿ȯ륷ʥ롣
-  //! \param strMessage å
-  void messageGenerated(const QString& strMessage);
 };
 
 #endif
