@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _WFILECHOOSER_H_
-#define _WFILECHOOSER_H_
+#ifndef WFILECHOOSER_H
+#define WFILECHOOSER_H
 
 #include <qhbox.h>
 #include <qlabel.h>
