@@ -2,17 +2,28 @@
                           wprefdialog.cpp  -  description
                              -------------------
     begin                : 2004ǯ  5  4  16:44:12 JST
-    copyright            : (C) 2003 by Black Sabbath
+    copyright            : (C) 2003 by Tomoaki Murakami
     email                : solarisphere@yahoo.co.jp
  ***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #include <sys/types.h>
@@ -28,6 +39,7 @@
 #include <kmessagebox.h>
 #include <kiconloader.h>
 #include <kglobal.h>
+#include <klocale.h>
 #include "wprefdialog.h"
 #include "cvoxstormglobal.h"
 
@@ -35,7 +47,7 @@
 
 WPrefDialog::WPrefDialog(QWidget *WidgetParent, const char *cName)
   : KDialogBase(KDialogBase::IconList,
-                "Configure VoxStorm", 
+                i18n("Configure"), 
                 Ok | Cancel,
                 Ok,
                 WidgetParent,
@@ -65,12 +77,12 @@ WPrefDialog::~WPrefDialog()
 /////////////////////////////////////////////////////////////////////////////
 
 void
-WPrefDialog::setFields(const SPreferences& PreferencesSet)
+WPrefDialog::setFields(const SPreferences& preferencesSet)
 {
-  FileChooserPlay->setFileName(PreferencesSet.strPlayDevice);
-  FileChooserRec->setFileName(PreferencesSet.strRecDevice);
+  FileChooserPlay->setFileName(preferencesSet.strPlayDevice);
+  FileChooserRec->setFileName(preferencesSet.strRecDevice);
  
-  switch ( PreferencesSet.FileType ) {
+  switch ( preferencesSet.FileType ) {
   case CVoxStormGlobal::ecaWAV:
     ComboBoxFileType->setCurrentItem(0);
     break;
@@ -81,9 +93,9 @@ WPrefDialog::setFields(const SPreferences& PreferencesSet)
     ComboBoxFileType->setCurrentItem(0);
     break;
   }
-  DirChooserProject->setFileName(PreferencesSet.strProjectPath);
+  DirChooserProject->setFileName(preferencesSet.strProjectPath);
 
-  switch ( PreferencesSet.uiSampleRate ) {
+  switch ( preferencesSet.uiSampleRate ) {
   case 44100:
     ComboBoxSampleRate->setCurrentItem(0);
     break;
@@ -97,7 +109,7 @@ WPrefDialog::setFields(const SPreferences& PreferencesSet)
     ComboBoxSampleRate->setCurrentItem(0);
     break;
   }
-  switch ( PreferencesSet.uiBuffer ) {
+  switch ( preferencesSet.uiBuffer ) {
   case 64:
     ComboBoxBuffer->setCurrentItem(0);
     break;
@@ -116,9 +128,10 @@ WPrefDialog::setFields(const SPreferences& PreferencesSet)
   }
 
   ListBoxTracks->clear();
-  ListBoxTracks->insertStringList(PreferencesSet.strlDefaultTracks);
+  ListBoxTracks->insertStringList(preferencesSet.strlDefaultTracks);
 
-  IntNumInputFrameSeconds->setValue(PreferencesSet.iFrameSeconds);
+  IntNumInputFrameSeconds->setValue(preferencesSet.iFrameSeconds);
+  TimeEditSessionMax->setTime(preferencesSet.timeSessionMax);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -126,35 +139,36 @@ WPrefDialog::setFields(const SPreferences& PreferencesSet)
 SPreferences
 WPrefDialog::fields()
 {
-  SPreferences PreferencesReturn;
-  PreferencesReturn.strPlayDevice = FileChooserPlay->fileName();
-  PreferencesReturn.strRecDevice = FileChooserRec->fileName();
+  SPreferences preferencesReturn;
+  preferencesReturn.strPlayDevice = FileChooserPlay->fileName();
+  preferencesReturn.strRecDevice = FileChooserRec->fileName();
 
   switch ( ComboBoxFileType->currentItem() ) {
   case 0:
-    PreferencesReturn.FileType = CVoxStormGlobal::ecaWAV;
+    preferencesReturn.FileType = CVoxStormGlobal::ecaWAV;
     break;
   case 1:
-    PreferencesReturn.FileType = CVoxStormGlobal::ecaMP3;
+    preferencesReturn.FileType = CVoxStormGlobal::ecaMP3;
     break;
   default:
-    PreferencesReturn.FileType = CVoxStormGlobal::ecaWAV;
+    preferencesReturn.FileType = CVoxStormGlobal::ecaWAV;
     break;
   }
-  PreferencesReturn.strProjectPath = DirChooserProject->fileName();
+  preferencesReturn.strProjectPath = DirChooserProject->fileName();
 
-  PreferencesReturn.uiSampleRate = ComboBoxSampleRate->currentText().toUInt();
-  PreferencesReturn.uiBuffer     = ComboBoxBuffer->currentText().toUInt();
+  preferencesReturn.uiSampleRate = ComboBoxSampleRate->currentText().toUInt();
+  preferencesReturn.uiBuffer     = ComboBoxBuffer->currentText().toUInt();
 
   int i, nTrack;
   nTrack = ListBoxTracks->count();
   for ( i = 0; i < nTrack; i++ ) {
-    PreferencesReturn.strlDefaultTracks.append(ListBoxTracks->item(i)->text());
+    preferencesReturn.strlDefaultTracks.append(ListBoxTracks->item(i)->text());
   }
 
-  PreferencesReturn.iFrameSeconds = IntNumInputFrameSeconds->value();
+  preferencesReturn.iFrameSeconds = IntNumInputFrameSeconds->value();
+  preferencesReturn.timeSessionMax = TimeEditSessionMax->time();
 
-  return PreferencesReturn;
+  return preferencesReturn;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -163,21 +177,22 @@ void
 WPrefDialog::setupDevicesPage()
 {
   QPixmap Pix = KGlobal::iconLoader()->loadIcon("voxstorm_hardware", KIcon::NoGroup, 32);
-  QVBox *VBoxDevices = addVBoxPage(QString("Devices"),
-                          "Detecting default devices for new track",
+  QVBox *VBoxDevices = addVBoxPage(
+                          QString(i18n("Devices")),
+                          i18n("Detecting default devices for new track"),
                           Pix);
   VBoxDevices->setMinimumHeight(120);
 
   // ǥХ
   FileChooserPlay = new WFileChooser("  Play", "Select device file", VBoxDevices);
   FileChooserPlay->setSearchDir("file:///dev");
-  FileChooserPlay->setFileType("*|All files");
+  FileChooserPlay->setFileType(i18n("*|All files (*)"));
   FileChooserPlay->setFileName("/dev/dsp");
 
   // ϿǥХ
   FileChooserRec = new WFileChooser("Record", "Select device file", VBoxDevices);
   FileChooserRec->setSearchDir("file:///dev");
-  FileChooserRec->setFileType("*|All files");
+  FileChooserRec->setFileType(i18n("*|All files (*)"));
   FileChooserRec->setFileName("/dev/dsp");
 }
 
@@ -187,14 +202,15 @@ void
 WPrefDialog::setupFilePage()
 {
   QPixmap Pix = KGlobal::iconLoader()->loadIcon("voxstorm_sound", KIcon::NoGroup, 32);
-  QVBox *VBoxFile = addVBoxPage(QString("File"),
-                          "Detecting file types etc", 
+  QVBox *VBoxFile = addVBoxPage(
+                          QString(i18n("File")),
+                          i18n("Detecting file types etc"), 
                           Pix);
   VBoxFile->setMinimumHeight(120);
 
   // ե륿׻ΤΥåȷꡣ
   QVGroupBox *GroupBoxFileType = new QVGroupBox(
-          "File type", VBoxFile);
+          i18n("File type"), VBoxFile);
   ComboBoxFileType = new KComboBox(GroupBoxFileType);
   ComboBoxFileType->insertItem("MP3 (*.mp3)");
   ComboBoxFileType->insertItem("WAVE (*.wav)");
@@ -202,10 +218,10 @@ WPrefDialog::setupFilePage()
 
   // ץȤΥǥե¸ѥΤΥåȷꡣ
   QVGroupBox *GroupBoxProjectPath = new QVGroupBox(
-          "VoxStorm session file saving directory", VBoxFile);
+          i18n("VoxStorm session file saving directory"), VBoxFile);
   DirChooserProject = new WFileChooser(
                             "",
-                            "Select VoxStorm session file saving directory",
+                            i18n("Select VoxStorm session file saving directory"),
                             GroupBoxProjectPath);
   DirChooserProject->setUsageForDir(true);
   DirChooserProject->setFileName("~/voxstorm");
@@ -217,14 +233,15 @@ void
 WPrefDialog::setupSoundSpecPage()
 {
   QPixmap Pix = KGlobal::iconLoader()->loadIcon("voxstorm_soundspec", KIcon::NoGroup, 32);
-  QVBox *VBoxSound = addVBoxPage(QString("Sound Spec"),
-                          "Detecting sound spec",
+  QVBox *VBoxSound = addVBoxPage(
+                          QString(i18n("Sound Spec")),
+                          i18n("Detecting sound spec"),
                           Pix);
   QGridLayout *GridLayout = new QGridLayout(VBoxSound, 2, 1);
 
   // sampling rate
   QHGroupBox *GroupBoxSampling = new QHGroupBox(
-          "Sampling rate", VBoxSound);
+          i18n("Sampling rate"), VBoxSound);
   GridLayout->addWidget(GroupBoxSampling, 0, 0);
   ComboBoxSampleRate = new KComboBox(GroupBoxSampling);
   ComboBoxSampleRate->insertItem("44100");
@@ -233,7 +250,7 @@ WPrefDialog::setupSoundSpecPage()
 
   // size of buffer in samples (must be an exponent of 2)
   QVGroupBox *GroupBoxBuffer   = new QVGroupBox(
-          "Buffer size in samples", VBoxSound);
+          i18n("Buffer size in samples"), VBoxSound);
   GridLayout->addWidget(GroupBoxBuffer, 1, 0);
   ComboBoxBuffer = new KComboBox(GroupBoxBuffer);
   ComboBoxBuffer->insertItem("64");
@@ -248,20 +265,20 @@ void
 WPrefDialog::setupTrackPage()
 {
   QPixmap Pix = KGlobal::iconLoader()->loadIcon("voxstorm_track", KIcon::NoGroup, 32);
-  QVBox *VBoxTrack = addVBoxPage(QString("Track"),
-                          "Detecting default tracks etc",
+  QVBox *VBoxTrack = addVBoxPage(QString(i18n("Track")),
+                          i18n("Detecting default tracks etc"),
                           Pix);
 
   // åΥǥեȥȥåΤΥåȷ
   QHGroupBox *GroupBoxTracks = new QHGroupBox(
-          "Default track names", VBoxTrack, "GroupBoxTracks");
+          i18n("Default track names"), VBoxTrack, "GroupBoxTracks");
 
   // ɲ
   LineEditName = new KRestrictedLine(GroupBoxTracks);
   LineEditName->setValidChars(CVoxStormGlobal::ValidCharsTrack);
   connect(LineEditName, SIGNAL(textChanged(const QString&)),
           this, SLOT(slotChangeAddState(const QString&)));
-  PushButtonAdd = new QPushButton("Add", GroupBoxTracks);
+  PushButtonAdd = new QPushButton(i18n("Add"), GroupBoxTracks);
   PushButtonAdd->setEnabled(false);
   connect(PushButtonAdd, SIGNAL(clicked()),
           this, SLOT(slotAddTrackToList()));
@@ -274,15 +291,15 @@ WPrefDialog::setupTrackPage()
   // ԽΤΥåȷꡣ
   QWidget     *WidgetBase = new QWidget(GroupBoxTracks);
   QGridLayout *GridLayout = new QGridLayout(WidgetBase, 5, 2);
-  PushButtonUp     = new QPushButton("Up", WidgetBase);
+  PushButtonUp     = new QPushButton(i18n("Up"), WidgetBase);
   GridLayout->addWidget(PushButtonUp, 0, 0);
   connect(PushButtonUp, SIGNAL(clicked()),
           this, SLOT(slotTrackUp()));
-  PushButtonDown   = new QPushButton("Down", WidgetBase);
+  PushButtonDown   = new QPushButton(i18n("Down"), WidgetBase);
   GridLayout->addWidget(PushButtonDown, 1, 0);
   connect(PushButtonDown, SIGNAL(clicked()),
           this, SLOT(slotTrackDown()));
-  PushButtonRemove = new QPushButton("Remove", WidgetBase);
+  PushButtonRemove = new QPushButton(i18n("Remove"), WidgetBase);
   GridLayout->addWidget(PushButtonRemove, 4, 0);
   connect(PushButtonRemove, SIGNAL(clicked()),
           this, SLOT(slotRemoveTrackFromList()));
@@ -294,15 +311,25 @@ void
 WPrefDialog::setupGenericPage()
 {
   QPixmap Pix = KGlobal::iconLoader()->loadIcon("voxstorm_generic", KIcon::NoGroup, 32);
-  QVBox *VBoxGeneric = addVBoxPage(QString("Generic"),
-                          "VoxStorm generic settings",
+  QVBox *VBoxGeneric = addVBoxPage(QString(i18n("General")),
+                          i18n("VoxStorm generic settings"),
                           Pix);
 
   // ᤷÿΤΥåȷ
   QHGroupBox *GroupBoxFrameSeconds = new QHGroupBox(
-          "Seconds of rewind and forward", VBoxGeneric, "GroupBoxFrameSeconds");
+          i18n("Seconds of rewind and forward"), VBoxGeneric, "GroupBoxFrameSeconds");
   IntNumInputFrameSeconds = new KIntNumInput(GroupBoxFrameSeconds);
   IntNumInputFrameSeconds->setRange(1, 240);
+
+  // åκ֤ꤹ뤿Υåȷ
+  QHGroupBox *GroupBoxSessionMax = new QHGroupBox(
+          i18n("Max time of one session"), 
+          VBoxGeneric, 
+          "GroupBoxSessionMax");
+  TimeEditSessionMax = new QTimeEdit(GroupBoxSessionMax);
+  TimeEditSessionMax->setDisplay(QTimeEdit::Hours | 
+                                 QTimeEdit::Minutes | 
+                                 QTimeEdit::Seconds);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -329,10 +356,16 @@ WPrefDialog::slotAddTrackToList()
 
   QListBoxItem *ItemFound = ListBoxTracks->findItem(strTrack);
   if ( ItemFound != NULL ) {
-    QString strMessage;
-    strMessage  = "The name \"";
-    strMessage += strTrack;
-    strMessage += "\" is already existing.";
+    QString strMessage = i18n("Track name : ");
+    strMessage = "\"" + strTrack + "\"\n";
+    strMessage += i18n("The name is already using in other track.\n"
+                       "Failed in adding track.");
+    KMessageBox::sorry(this, strMessage);
+    return;
+  } else if ( !CVoxStormGlobal::isValidTrackName(strTrack) ) {
+    QString strMessage = 
+                QString(i18n("The name \"%1\" cannot be used for "
+                             "track name.\nFailed in adding track.").arg(strTrack));
     KMessageBox::sorry(this, strMessage);
     return;
   }
