@@ -7,20 +7,31 @@
  ***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 /////////////////////////////////////////////////////////////////////////////
 
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qscrollview.h>
 #include <qsplitter.h>
+#include <qscrollview.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include "wvoxbase.h"
@@ -80,14 +91,17 @@ WVoxBase::addTrack(const QString& strDeviceIn, const QString& strDeviceOut)
     if ( queryExistingTrackName(strTrackName)) { // already exsists
       QString strMessage = i18n("Track name : ");
       strMessage = "\"" + strTrackName + "\"\n";
-      strMessage += i18n("The track name is already existing.\n"
+      strMessage += i18n("The name is already usiing in other track.\n"
                          "Failed in adding track.");
       KMessageBox::sorry(this, strMessage);
+      return;
 
-    } else if ( strTrackName == "all" ) {
+    } else if ( !CVoxStormGlobal::isValidTrackName(strTrackName) ) {
       QString strMessage = 
-                i18n("The name \"all\" cannot be used for "
-                     "track name.\nFailed in adding track.");
+                QString(i18n("The name \"%1\" cannot be used for "
+                     "track name.\nFailed in adding track.").arg(strTrackName));
+      KMessageBox::sorry(this, strMessage);
+      return;
     } else {
       addTrack(strTrackName, strDeviceIn, strDeviceOut);
     }
@@ -147,6 +161,9 @@ WVoxBase::addTrack(
   connect(VoxTrackNew, SIGNAL(lengthChanged(const QTime&)), 
           SignalMapperLength, SLOT(map()));
 
+  connect(VoxTrackNew, SIGNAL(locatorScrolled(QObject*, int)), 
+          this, SLOT(slotSetScrollToAll(QObject*, int)));
+
   vVoxTracks.push_back(VoxTrackNew);
   VoxTrackNew->show();
 }
@@ -206,6 +223,9 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
     connect(VoxTrackNew, SIGNAL(lengthChanged(const QTime&)),
             SignalMapperLength, SLOT(map()));
 
+    connect(VoxTrackNew, SIGNAL(locatorScrolled(QObject*, int)), 
+            this, SLOT(slotSetScrollToAll(QObject*, int)));
+
     vVoxTracks.push_back(VoxTrackNew);
     VoxTrackNew->show();
   }
@@ -392,6 +412,8 @@ WVoxBase::setupWidgets()
 
   QSplitter   *Splitter = new QSplitter(Vertical, VBoxBase);
   QScrollView *ScrollView = new QScrollView(Splitter);
+  ScrollView->setHScrollBarMode(QScrollView::AlwaysOff);
+  ScrollView->setVScrollBarMode(QScrollView::AlwaysOn);
 
   VBoxTracks = new QVBox(Splitter);
   VBoxTracks->setMinimumHeight(300);
@@ -458,6 +480,7 @@ WVoxBase::ecasoundCmd() const
 }
 
 /////////////////////////////////////////////////////////////////////////////
+
 QDomNode
 WVoxBase::stateInDOM(QDomDocument* pDoc)
 {
@@ -473,6 +496,21 @@ WVoxBase::stateInDOM(QDomDocument* pDoc)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxBase::resizeEvent(QResizeEvent* Event)
+{
+  QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
+  VBoxTracks->resize(Event->size().width() - 24, VBoxTracks->height());
+  while ( it != vVoxTracks.end() ) {
+    (*it)->resize(Event->size().width() - 24, (*it)->height());
+    it++;
+  }
+
+  QVBox::resizeEvent(Event);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 WVoxBase::slotWriteConsoleMessage(const QString& strMessage)
 {
@@ -548,9 +586,9 @@ WVoxBase::slotNotifySucceedInRecording()
 
   while ( it != vVoxTracks.end() ) {
     if ( (*it)->isSetRec() ) {
-      (*it)->setStartPosition(QTime(0,0));
-      (*it)->setOffset(QTime(0,0));
-      (*it)->setLength(QTime(0,0));
+      (*it)->slotSetStartPosition(QTime(0,0));
+      (*it)->slotSetOffset(QTime(0,0));
+      (*it)->slotSetLength(QTime(0,0));
     }
     it++;
   }  
@@ -567,9 +605,9 @@ WVoxBase::slotAddTrack()
 /////////////////////////////////////////////////////////////////////////////
 
 void
-WVoxBase::slotChangePosition(const QTime& Time)
+WVoxBase::slotChangePosition(const QTime& time)
 {
-  TimeEditPosition->setTime(Time);
+  TimeEditPosition->setTime(time);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -673,4 +711,24 @@ WVoxBase::slotChangeLength(const QString& strTrackName)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxBase::slotSetScrollToAll(QObject* ObjectSender, int x)
+{
+  QValueVector<WVoxTrack*>::iterator it = vVoxTracks.begin();
+
+  it = vVoxTracks.begin();
+  while ( it != vVoxTracks.end() ) {
+    if ( (*it) != ObjectSender ) {
+      disconnect(*it, SIGNAL(locatorScrolled(QObject*, int)), 
+                 this, SLOT(slotSetScrollToAll(QObject*, int)));
+      (*it)->scrollLocator(x);
+      connect(*it, SIGNAL(locatorScrolled(QObject*, int)), 
+              this, SLOT(slotSetScrollToAll(QObject*, int)));
+    }
+    it++;
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 #include "wvoxbase.moc"
