@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _WVOXBASE_H_
-#define _WVOXBASE_H_
+#ifndef WVOXBASE_H
+#define WVOXBASE_H
 
 #include <qsignalmapper.h>
 #include <qvbox.h>
@@ -65,7 +65,7 @@ public:
   //! \param cName åȤ̾Ρ
   WVoxBase(const QDomNode& nodBase, QWidget* WidgetParent=0, const char *cName=0);
   //! \briefǥȥ饯
-  ~WVoxBase();
+  virtual ~WVoxBase();
 
   //! \brief ȥåɲäԤ
   //! addTrack(const QString& strTrackName)Υåѡؿ
@@ -125,6 +125,9 @@ public:
   //! \return DOMΡɡ
   QDomNode stateInDOM(QDomDocument* pDoc);
 
+protected:
+  void resizeEvent(QResizeEvent* Event);
+
 private:
   //! ϰ֤ɽ뤿Υåȡ
   QTimeEdit     *TimeEditPosition;
@@ -188,7 +191,7 @@ private slots:
   //! \brief ȥåɲ׵Ф륹åȡ
   void slotAddTrack();
   //! \brief ϰ֤ѹ륹åȡ
-  void slotChangePosition(const QTime& Time);
+  void slotChangePosition(const QTime& time);
 
   //! \brief ץ쥤ХåǥХѹФ륹åȡ
   void slotChangePlaybackDevice(const QString& strTrackName);
@@ -228,6 +231,9 @@ private slots:
   //! \param strTrackName ȥå̾Ρ
   void slotChangeLength(const QString& strTrackName);
 
+  //! \brief ȥåΥΥ碌륹åȡ
+  void slotSetScrollToAll(QObject* ObjectSender, int x);
+
 signals:
   //! \brief ޥݥѹΥʥ롣
   void masterPositionChanged(const QTime&);
