@@ -7,12 +7,23 @@
  ***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #include <unistd.h>
@@ -131,34 +142,37 @@ WVoxStorm::readConfigurationFile()
   QString   strTmp;
   QStrList  strListTmp;
 
-  // ---->>>> setting for Preferences member
+  // ---->>>> setting for preferences member
   Config->setGroup("Devices");
-  Preferences.strPlayDevice = Config->readEntry("PlaybackDevice", "/dev/dsp");
-  Preferences.strRecDevice  = Config->readEntry("RecDevice", "/dev/dsp");
+  preferences.strPlayDevice = Config->readEntry("PlaybackDevice", "/dev/dsp");
+  preferences.strRecDevice  = Config->readEntry("RecDevice", "/dev/dsp");
 
   Config->setGroup("File");
   strTmp = Config->readEntry("FileType", "WAV");
   if ( strTmp == "WAV" ) {
-    Preferences.FileType = CVoxStormGlobal::ecaWAV;
+    preferences.FileType = CVoxStormGlobal::ecaWAV;
   } else {
-    Preferences.FileType = CVoxStormGlobal::ecaMP3;
+    preferences.FileType = CVoxStormGlobal::ecaMP3;
   }
 
   Config->setGroup("Project");
-  Preferences.strProjectPath = Config->readEntry("ProjectPath", "~/voxstorm");
+  preferences.strProjectPath = Config->readEntry("ProjectPath", "~/voxstorm");
 
   Config->setGroup("Sound Spec");
-  Preferences.uiSampleRate = Config->readNumEntry("SamplingRate", 44100);
-  Preferences.uiBuffer     = Config->readNumEntry("BufferSize", 256);
+  preferences.uiSampleRate = Config->readNumEntry("SamplingRate", 44100);
+  preferences.uiBuffer     = Config->readNumEntry("BufferSize", 256);
 
   Config->setGroup("Track");
   Config->readListEntry("DefaultTracks", strListTmp, ',');
-  Preferences.strlDefaultTracks.clear();
-  Preferences.strlDefaultTracks = QStringList::fromStrList(strListTmp);
+  preferences.strlDefaultTracks.clear();
+  preferences.strlDefaultTracks = QStringList::fromStrList(strListTmp);
 
   Config->setGroup("Generic");
-  Preferences.iFrameSeconds = Config->readNumEntry("FrameSeconds", 5);
-  // <<<<---- setting for Preferences member
+  preferences.iFrameSeconds = Config->readNumEntry("FrameSeconds", 5);
+  QTime timeTmp;
+  preferences.timeSessionMax = 
+    timeTmp.addSecs(Config->readNumEntry("SessionMaxSecs", 1000));
+  // <<<<---- setting for preferences member
 
   // ---->>>> setting for Mainwindow
   Config->setGroup("Mainwindow");
@@ -181,34 +195,37 @@ WVoxStorm::writeConfigurationFile()
 
   // ---->>>> setting for Mainwindow
   Config->setGroup("Devices");
-  Config->writeEntry("PlayDevice", Preferences.strPlayDevice);
-  Config->writeEntry("RecDevice", Preferences.strRecDevice);
+  Config->writeEntry("PlayDevice", preferences.strPlayDevice);
+  Config->writeEntry("RecDevice", preferences.strRecDevice);
 
   Config->setGroup("File");
-  if ( Preferences.FileType == CVoxStormGlobal::ecaWAV ) {
+  if ( preferences.FileType == CVoxStormGlobal::ecaWAV ) {
     Config->writeEntry("FileType", "WAV");
   } else {
     Config->writeEntry("FileType", "MP3");
   }
 
   Config->setGroup("Project");
-  Config->writeEntry("ProjectPath", Preferences.strProjectPath);
+  Config->writeEntry("ProjectPath", preferences.strProjectPath);
 
   Config->setGroup("Sound Spec");
-  Config->writeEntry("SamplingRate", Preferences.uiSampleRate);
-  Config->writeEntry("BufferSize", Preferences.uiBuffer);
+  Config->writeEntry("SamplingRate", preferences.uiSampleRate);
+  Config->writeEntry("BufferSize", preferences.uiBuffer);
 
   QStrList  strListTmp;
   int       i, nTrack;
   Config->setGroup("Track");
-  nTrack = Preferences.strlDefaultTracks.count();
+  nTrack = preferences.strlDefaultTracks.count();
   for ( i = 0; i < nTrack; i++ ) {
-    strListTmp.append(Preferences.strlDefaultTracks[i]);
+    strListTmp.append(preferences.strlDefaultTracks[i]);
   }
   Config->writeEntry("DefaultTracks", strListTmp, ',');
 
   Config->setGroup("Generic");
-  Config->writeEntry("FrameSeconds", Preferences.iFrameSeconds);
+  Config->writeEntry("FrameSeconds", preferences.iFrameSeconds);
+  QTime timeTmp;
+  Config->writeEntry("SessionMaxSecs", 
+                     timeTmp.secsTo(preferences.timeSessionMax));
   // <<<<---- setting for Mainwindow
 
   // ---->>>> setting for Mainwindow
@@ -387,13 +404,7 @@ WVoxStorm::setupActions()
   ToggleActionInteractive->plug(toolBar());
   ToggleActionInteractive->setEnabled(false);
 
-  Action = new KAction(i18n("&Configure VoxStorm..."),
-                       NULL,
-                       "configure",
-                       this,
-                       SLOT(slotPreferences()),
-                       actionCollection(),
-                       "Configure");
+  Action = KStdAction::preferences(this, SLOT(slotPreferences()), actionCollection());
   Action->plug(PopupMenu);
 
   menuBar()->insertItem(i18n("&Settings"), PopupMenu);
@@ -637,13 +648,13 @@ WVoxStorm::slotNew()
 
     int     i, nTrack;
     QString strNewTrack;
-    nTrack = Preferences.strlDefaultTracks.count();
+    nTrack = preferences.strlDefaultTracks.count();
     for ( i = 0; i < nTrack; i++ ) {
-      strNewTrack = Preferences.strlDefaultTracks[i];
+      strNewTrack = preferences.strlDefaultTracks[i];
       if ( !VoxBase->queryExistingTrackName(strNewTrack) ) {
-	VoxBase->addTrack(Preferences.strlDefaultTracks[i],
-			  Preferences.strPlayDevice, 
-			  Preferences.strRecDevice);
+        VoxBase->addTrack(preferences.strlDefaultTracks[i],
+                          preferences.strPlayDevice,
+                          preferences.strRecDevice);
       }
     }
 
@@ -809,7 +820,7 @@ WVoxStorm::slotRewind()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {    
-    EcaIAManager.slotRewind(Preferences.iFrameSeconds);
+    EcaIAManager.slotRewind(preferences.iFrameSeconds);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -821,7 +832,7 @@ WVoxStorm::slotForward()
 {
   QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotForward(Preferences.iFrameSeconds);
+    EcaIAManager.slotForward(preferences.iFrameSeconds);
   }
   QApplication::restoreOverrideCursor();
 }
@@ -877,9 +888,9 @@ void
 WVoxStorm::slotPreferences()
 {
   WPrefDialog prefDialog(this);
-  prefDialog.setFields(Preferences);
+  prefDialog.setFields(preferences);
   if ( prefDialog.exec() == QDialog::Accepted ) {
-    Preferences = prefDialog.fields();
+    preferences = prefDialog.fields();
   }
 
   writeConfigurationFile();
@@ -906,7 +917,7 @@ WVoxStorm::slotInteractive()
 void
 WVoxStorm::slotAddTrack()
 {
-  VoxBase->addTrack(Preferences.strPlayDevice, Preferences.strRecDevice);
+  VoxBase->addTrack(preferences.strPlayDevice, preferences.strRecDevice);
 }
 
 /////////////////////////////////////////////////////////////////////////////
