@@ -7,16 +7,27 @@
 /***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#ifndef _WVOXSTORM_H_
-#define _WVOXSTORM_H_
+#ifndef WVOXSTORM_H
+#define WVOXSTORM_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -57,11 +68,11 @@ public:
   //! \param cName åȤ̾Ρ
   WVoxStorm(const QString& strFileName, QWidget* WidgetParent=0, const char *cName=0);
   //! \brief ǥȥ饯
-  ~WVoxStorm();
+  virtual ~WVoxStorm();
 
-  //! \brief եξPreferencesɤ߹ࡣ
+  //! \brief եξpreferencesɤ߹ࡣ
   void readConfigurationFile();
-  //! \brief եPreferecesξ񤭹ࡣ
+  //! \brief եpreferecesξ񤭹ࡣ
   void writeConfigurationFile();
 
 protected:
@@ -78,7 +89,7 @@ private:
   //! Ecasound-IAޥ͡㡣
   CEcaIAManager EcaIAManager;
   //! 
-  SPreferences Preferences;
+  SPreferences preferences;
   //! DOMɥ
   QDomDocument  *pDocVox;
   //! Ͽ˥塼ID
@@ -210,4 +221,4 @@ private slots:
   void slotFinish();
 };
 
-#endif // _WVOXSTORM_H_
+#endif // WVOXSTORM_H
