@@ -2,20 +2,33 @@
                           wvoxtrack.cpp  -  description
                              -------------------
     begin                : 2004ǯ  5  4  17:01:12 JST
-    copyright            : (C) 2003 by Black Sabbath
+    copyright            : (C) 2003 by Tomoaki Murakami
     email                : solarisphere@yahoo.co.jp
  ***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #include <qcursor.h>
+#include <qlayout.h>
+#include <qscrollview.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <klineeditdlg.h>
@@ -42,7 +55,7 @@ WVoxTrack::WVoxTrack(const QString& strName,
                      const QString& strDeviceOut,
                      QWidget*       WidgetParent,
                      const char*    cName)
-  : QHBox(WidgetParent, cName)
+  : QWidget(WidgetParent, cName)
 {
   strInputDevice = strDeviceIn;
   strOutputDevice = strDeviceOut;
@@ -52,13 +65,13 @@ WVoxTrack::WVoxTrack(const QString& strName,
 
 /////////////////////////////////////////////////////////////////////////////
 
-WVoxTrack::WVoxTrack(const CTrackInf& TrackInf,
+WVoxTrack::WVoxTrack(const CTrackInf& trackInf,
                      QWidget*         WidgetParent, 
                      const char*      cName)
-  : QHBox(WidgetParent, cName)
+  : QWidget(WidgetParent, cName)
 {
   setupWidgets();
-  setStateByTrackInf(TrackInf);
+  setStateByTrackInf(trackInf);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -66,7 +79,7 @@ WVoxTrack::WVoxTrack(const CTrackInf& TrackInf,
 WVoxTrack::WVoxTrack(const QDomNode& nodTrack,
                      QWidget*        WidgetParent, 
                      const char*     cName)
-  : QHBox(WidgetParent, cName)
+  : QWidget(WidgetParent, cName)
 {
   setupWidgets();
   setStateByDom(nodTrack);
@@ -84,11 +97,14 @@ void
 WVoxTrack::setupWidgets()
 {
   // this has VBoxController
+  QHBoxLayout* HBoxLayout = new QHBoxLayout(this);
+  
   setupPopupMenu();
-  setMinimumWidth(400);
-  setFrameStyle(QFrame::WinPanel | QFrame::Plain);
+  QHBox* HBoxTop = new QHBox(this);
+  HBoxTop->setFrameStyle(QFrame::WinPanel | QFrame::Plain);
+  HBoxLayout->addWidget(HBoxTop);
 
-  VBoxController = new QVBox(this);
+  VBoxController = new QVBox(HBoxTop);
 
   // VBoxController has HBoxStandard, HBoxButtonBase
   HBoxStandard = new QHBox(VBoxController);
@@ -119,7 +135,7 @@ WVoxTrack::setupWidgets()
   // HBoxButtonBase has FileChooserTrack, WidgetSpacer, ColorButtonMute, ColorButtonRec
   FileChooserTrack = new WFileChooser("", i18n("Detect sound source file"), HBoxButtonBase);
   FileChooserTrack->setFileType(i18n("*.wav *.mp3|Sound files (*.wav; *.mp3)\n*"
-                                "|All files (*)"));
+                                     "|All files (*)"));
 
   WidgetSpacer = new QHBox(HBoxButtonBase);
   WidgetSpacer->setMinimumWidth(10);
@@ -131,7 +147,7 @@ WVoxTrack::setupWidgets()
   PushButtonMute->setText("M");
   PushButtonMute->setToggleButton(true);
   PushButtonMute->setOn(false);
-  PushButtonMute->setMaximumWidth(20);
+  PushButtonMute->setMaximumWidth(PushButtonMute->sizeHint().width());
 
   // record button
   PushButtonRec = new QPushButton(HBoxButtonBase);
@@ -139,15 +155,34 @@ WVoxTrack::setupWidgets()
   PushButtonRec->setText("R");
   PushButtonRec->setToggleButton(true);
   PushButtonRec->setOn(false);
-  PushButtonRec->setMaximumWidth(20);
+  PushButtonRec->setMaximumWidth(PushButtonRec->sizeHint().width());
+
+  HBoxTop->setMaximumWidth(350);
+  HBoxTop->setMinimumWidth(350);
+
+  Locator = new WSoundLocator(this);
+  HBoxLayout->addWidget(Locator, 100);
+  Locator->setBaseColor(QColor(0, 0, 0));
+  Locator->setItemFaceColor(QColor(111, 109, 158));
+  Locator->setItemEdgeColor(QColor(138, 136, 197));
 
   // setup signals and slots
   connect(FileChooserTrack, SIGNAL(fileNameChanged(const QString&)),
-	  this, SIGNAL(fileNameChanged(const QString&)));
+          this, SLOT(slotChangedFileName(const QString&)));
+  connect(FileChooserTrack, SIGNAL(fileNameChanged(const QString&)),
+          this, SIGNAL(fileNameChanged(const QString&)));
   connect(IntNumInputLevel, SIGNAL(valueChanged(int)), this, SIGNAL(levelChanged(int)));
   connect(IntNumInputPan, SIGNAL(valueChanged(int)), this, SIGNAL(panChanged(int)));
   connect(PushButtonMute, SIGNAL(toggled(bool)), this, SIGNAL(muteToggled(bool)));
   connect(PushButtonRec, SIGNAL(toggled(bool)), this, SIGNAL(recToggled(bool)));
+  connect(Locator, SIGNAL(startPositionChanged(const QTime&)), 
+          this, SLOT(slotSetStartPosition(const QTime&)));
+  connect(Locator, SIGNAL(offsetChanged(const QTime&)), 
+          this, SLOT(slotSetOffset(const QTime&)));
+  connect(Locator, SIGNAL(lengthChanged(const QTime&)), 
+          this, SLOT(slotSetLength(const QTime&)));
+  connect(Locator, SIGNAL(contentsMoving(int, int)), 
+          this, SLOT(slotMovedContents(int)));
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -230,7 +265,7 @@ WVoxTrack::fileName() const
 QTime
 WVoxTrack::startPosition() const
 {
-  return TimeStartPosition;
+  return timeStartPosition;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -238,7 +273,7 @@ WVoxTrack::startPosition() const
 QTime
 WVoxTrack::offset() const
 {
-  return TimeOffset;
+  return timeOffset;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -246,7 +281,7 @@ WVoxTrack::offset() const
 QTime
 WVoxTrack::length() const
 {
-  return TimeLength;
+  return timeLength;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -278,21 +313,21 @@ WVoxTrack::isBindedToFile() const
 CTrackInf 
 WVoxTrack::stateInTrackInf() const
 {
-  CTrackInf TrackInfReturn;
+  CTrackInf trackInfReturn;
 
-  TrackInfReturn.strTrackName    = LabelName->text();
-  TrackInfReturn.strFileName     = FileChooserTrack->fileName();
-  TrackInfReturn.strInputDevice  = strInputDevice;
-  TrackInfReturn.strOutputDevice = strOutputDevice;
-  TrackInfReturn.nLevel          = IntNumInputLevel->value();
-  TrackInfReturn.nPan            = IntNumInputPan->value();
-  TrackInfReturn.TimeStartPosition  = TimeStartPosition;
-  TrackInfReturn.TimeOffset      = TimeOffset;
-  TrackInfReturn.TimeLength      = TimeLength;
-  TrackInfReturn.bMute           = PushButtonMute->isOn();
-  TrackInfReturn.bRecPort        = PushButtonRec->isOn();
+  trackInfReturn.strTrackName    = LabelName->text();
+  trackInfReturn.strFileName     = FileChooserTrack->fileName();
+  trackInfReturn.strInputDevice  = strInputDevice;
+  trackInfReturn.strOutputDevice = strOutputDevice;
+  trackInfReturn.nLevel          = IntNumInputLevel->value();
+  trackInfReturn.nPan            = IntNumInputPan->value();
+  trackInfReturn.TimeStartPosition  = timeStartPosition;
+  trackInfReturn.TimeOffset      = timeOffset;
+  trackInfReturn.TimeLength      = timeLength;
+  trackInfReturn.bMute           = PushButtonMute->isOn();
+  trackInfReturn.bRecPort        = PushButtonRec->isOn();
 
-  return TrackInfReturn;
+  return trackInfReturn;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -359,24 +394,24 @@ WVoxTrack::stateInDOM(QDomDocument* pDoc) const
   // start position
   {
     QDomElement eleStartPosition = pDoc->createElement("StartPosition");
-    QTime TimeTmp;
-    eleStartPosition.setAttribute("value", TimeTmp.msecsTo(TimeStartPosition));
+    QTime timeTmp;
+    eleStartPosition.setAttribute("value", timeTmp.msecsTo(timeStartPosition));
     eleTrack.appendChild(eleStartPosition);
   }
 
   // offset
   {
     QDomElement eleOffset = pDoc->createElement("Offset");
-    QTime TimeTmp;
-    eleOffset.setAttribute("value", TimeTmp.msecsTo(TimeOffset));
+    QTime timeTmp;
+    eleOffset.setAttribute("value", timeTmp.msecsTo(timeOffset));
     eleTrack.appendChild(eleOffset);
   }
 
   // length
   {
     QDomElement eleLength = pDoc->createElement("Length");
-    QTime TimeTmp;
-    eleLength.setAttribute("value", TimeTmp.msecsTo(TimeLength));
+    QTime timeTmp;
+    eleLength.setAttribute("value", timeTmp.msecsTo(timeLength));
     eleTrack.appendChild(eleLength);
   }
 
@@ -417,30 +452,6 @@ WVoxTrack::setFileName(const QString& strFileName)
 
 /////////////////////////////////////////////////////////////////////////////
 
-void
-WVoxTrack::setStartPosition(const QTime& TimeStartPositionArg)
-{
-  TimeStartPosition = TimeStartPositionArg;
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
-void
-WVoxTrack::setOffset(const QTime& TimeOffsetArg)
-{
-  TimeOffset = TimeOffsetArg;
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
-void
-WVoxTrack::setLength(const QTime& TimeLengthArg)
-{
-  TimeLength = TimeLengthArg;
-}
-
-/////////////////////////////////////////////////////////////////////////////
-
 void
 WVoxTrack::setMute(bool bMute)
 {
@@ -458,19 +469,19 @@ WVoxTrack::setRec(bool bRecPort)
 /////////////////////////////////////////////////////////////////////////////
 
 void
-WVoxTrack::setStateByTrackInf(const CTrackInf& TrackInfSet)
+WVoxTrack::setStateByTrackInf(const CTrackInf& trackInfSet)
 {
-  LabelName->setText(TrackInfSet.strTrackName);
-  FileChooserTrack->setFileName(TrackInfSet.strFileName);
-  strInputDevice  = TrackInfSet.strInputDevice;
-  strOutputDevice = TrackInfSet.strOutputDevice;
-  IntNumInputLevel->setValue(TrackInfSet.nLevel);
-  IntNumInputPan->setValue(TrackInfSet.nPan);
-  TimeStartPosition = TrackInfSet.TimeStartPosition;
-  TimeOffset        = TrackInfSet.TimeOffset;
-  TimeLength        = TrackInfSet.TimeLength;
-  PushButtonMute->setOn(TrackInfSet.bMute);
-  PushButtonRec->setOn(TrackInfSet.bRecPort);
+  LabelName->setText(trackInfSet.strTrackName);
+  FileChooserTrack->setFileName(trackInfSet.strFileName);
+  strInputDevice  = trackInfSet.strInputDevice;
+  strOutputDevice = trackInfSet.strOutputDevice;
+  IntNumInputLevel->setValue(trackInfSet.nLevel);
+  IntNumInputPan->setValue(trackInfSet.nPan);
+  timeStartPosition = trackInfSet.TimeStartPosition;
+  timeOffset        = trackInfSet.TimeOffset;
+  timeLength        = trackInfSet.TimeLength;
+  PushButtonMute->setOn(trackInfSet.bMute);
+  PushButtonRec->setOn(trackInfSet.bRecPort);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -562,7 +573,7 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
   // start position
   {
     QDomNode nodStartPosition = nolChildren.item(4);
-    TimeStartPosition = QTime();
+    timeStartPosition = QTime();
     if ( nodStartPosition.isNull() ){
       ;
     } else {
@@ -571,7 +582,7 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
         ;
       } else {
         QDomNode nodValue = nnmAttributes.namedItem("value");
-        TimeStartPosition.addMSecs(nodValue.nodeValue().toInt());
+        timeStartPosition.addMSecs(nodValue.nodeValue().toInt());
       }
     }
   }
@@ -579,7 +590,7 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
   // offset
   {
     QDomNode nodOffset = nolChildren.item(5);
-    TimeOffset = QTime();
+    timeOffset = QTime();
     if ( nodOffset.isNull() ){
       ;
     } else {
@@ -588,7 +599,7 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
         ;
       } else {
         QDomNode nodValue = nnmAttributes.namedItem("value");
-        TimeOffset.addMSecs(nodValue.nodeValue().toInt());
+        timeOffset.addMSecs(nodValue.nodeValue().toInt());
       }
     }
   }
@@ -596,7 +607,7 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
   // length
   {
     QDomNode nodLength = nolChildren.item(6);
-    TimeLength = QTime();
+    timeLength = QTime();
     if ( nodLength.isNull() ){
       ;
     } else {
@@ -605,7 +616,7 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
         ;
       } else {
         QDomNode nodValue = nnmAttributes.namedItem("value");
-        TimeLength.addMSecs(nodValue.nodeValue().toInt());
+        timeLength.addMSecs(nodValue.nodeValue().toInt());
       }
     }
   }
@@ -613,6 +624,18 @@ WVoxTrack::setStateByDom(const QDomNode& nodTrack)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::scrollLocator(int x)
+{
+  disconnect(Locator, SIGNAL(contentsMoving(int, int)), 
+          this, SLOT(slotMovedContents(int)));
+  Locator->setContentsPos(x, Locator->contentsY());
+  connect(Locator, SIGNAL(contentsMoving(int, int)), 
+          this, SLOT(slotMovedContents(int)));
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxTrack::mousePressEvent(QMouseEvent* MouseEvent)
 {
@@ -655,10 +678,57 @@ WVoxTrack::slotSetEnabledWidgets(unsigned int unWidgets, bool bEnabled)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::slotSetStartPosition(const QTime& time)
+{
+  if ( timeStartPosition == time ) {
+    return;
+  }
+
+  timeStartPosition = time;
+  emit startPositionChanged(timeStartPosition);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+WVoxTrack::slotSetOffset(const QTime& time)
+{
+  if ( timeOffset == time ) {
+    return;
+  }
+
+  timeOffset = time;
+  emit offsetChanged(timeOffset);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+WVoxTrack::slotSetLength(const QTime& time)
+{
+ if ( timeLength == time ) {
+    return;
+  }
+
+  timeLength = time;
+  emit lengthChanged(timeLength);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+WVoxTrack::slotChangedFileName(const QString& strFileName)
+{
+  Locator->bind(strFileName);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxTrack::slotChangePlaybackDevice()
 {
-  KLineEditDlg lineEditDlg("Playback device of this track",
+  KLineEditDlg lineEditDlg(i18n("Playback device of this track"),
                            strOutputDevice, this);
   if ( lineEditDlg.exec() == QDialog::Accepted ) {
     strOutputDevice = lineEditDlg.text();
@@ -671,7 +741,7 @@ WVoxTrack::slotChangePlaybackDevice()
 void 
 WVoxTrack::slotChangeRecordingDevice()
 {
-  KLineEditDlg lineEditDlg("Recording device of this track",
+  KLineEditDlg lineEditDlg(i18n("Recording device of this track"),
                            strInputDevice, this);
   if ( lineEditDlg.exec() == QDialog::Accepted ) {
     strInputDevice = lineEditDlg.text();
@@ -684,7 +754,7 @@ WVoxTrack::slotChangeRecordingDevice()
 void
 WVoxTrack::slotRemove()
 {
-  QString strMessage = "Are you sure to remove this track?";
+  QString strMessage = i18n("Are you sure to remove this track?");
   if ( KMessageBox::questionYesNo(this, strMessage) == KMessageBox::Yes ) {
     emit removed();
   }
@@ -705,14 +775,14 @@ WVoxTrack::slotChangeStartPosition()
 {
   WTimeDialog timeDialog(this);
 
-  timeDialog.setCaption("Set Start Position");
-  timeDialog.setTime(TimeStartPosition);
+  timeDialog.setCaption(i18n("Set Start Position"));
+  timeDialog.setTime(timeStartPosition);
   timeDialog.setDisplay(
       WTimeDialog::Minutes | WTimeDialog::Seconds | WTimeDialog::MilliSecs);
 
   if ( timeDialog.exec() == QDialog::Accepted ) {
-    TimeStartPosition = timeDialog.time();
-    emit startPositionChanged(TimeStartPosition);
+    slotSetStartPosition(timeDialog.time());
+    Locator->slotSetStartPosition(timeDialog.time());//!!
   }
 }
 
@@ -723,14 +793,14 @@ WVoxTrack::slotChangeOffset()
 {
   WTimeDialog timeDialog(this);
 
-  timeDialog.setCaption("Set Offset from Origin");
-  timeDialog.setTime(TimeOffset);
+  timeDialog.setCaption(i18n("Set Offset from Origin"));
+  timeDialog.setTime(timeOffset);
   timeDialog.setDisplay(
       WTimeDialog::Minutes | WTimeDialog::Seconds | WTimeDialog::MilliSecs);
 
   if ( timeDialog.exec() == QDialog::Accepted ) {
-    TimeOffset = timeDialog.time();
-    emit offsetChanged(TimeOffset);
+    slotSetOffset(timeDialog.time());
+    Locator->slotSetOffset(timeDialog.time());//!!
   }
 }
 
@@ -741,17 +811,25 @@ WVoxTrack::slotChangeLength()
 {
   WTimeDialog timeDialog(this);
 
-  timeDialog.setCaption("Set Length for Playing Time");
-  timeDialog.setTime(TimeLength);
+  timeDialog.setCaption(i18n("Set Length for Playing Time"));
+  timeDialog.setTime(timeLength);
   timeDialog.setDisplay(
       WTimeDialog::Minutes | WTimeDialog::Seconds | WTimeDialog::MilliSecs);
 
   if ( timeDialog.exec() == QDialog::Accepted ) {
-    TimeLength = timeDialog.time();
-    emit lengthChanged(TimeLength);
+    slotSetLength(timeDialog.time());
+    Locator->slotSetLength(timeDialog.time());//!!
   }
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::slotMovedContents(int x)
+{
+  emit locatorScrolled(this, x);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 #include "wvoxtrack.moc"
