@@ -7,26 +7,37 @@
 /***************************************************************************/
 
 /***************************************************************************
+ *   Copyright (C) 2004 by Tomoaki Murakami                                *
+ *   solarisphrere@yahoo.co.jp                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#ifndef _WVOXTRACK_H_
-#define _WVOXTRACK_H_
+#ifndef WVOXTRACK_H
+#define WVOXTRACK_H
 
 #include <qhbox.h>
 #include <qvbox.h>
 #include <qlabel.h>
-#include <qlayout.h>
 #include <qpopupmenu.h>
 #include <qpushbutton.h>
 #include <qdom.h>
 #include <knuminput.h>
 #include "wfilechooser.h"
+#include "wsoundlocator.h"
 #include "ctrackinf.h"
 
 /*-------------------------------------------------------------------------*/
@@ -41,7 +52,7 @@
     ʸȤʤʤФʤʤ
 */
 /*-------------------------------------------------------------------------*/
-class WVoxTrack : public QHBox
+class WVoxTrack : public QWidget
 {
   Q_OBJECT
 
@@ -58,10 +69,10 @@ public:
             QWidget*       WidgetParent=0,
             const char*    cName=0);
   //! \brief 󥹥ȥ饯
-  //! \param TrackInf ȥå
+  //! \param trackInf ȥå
   //! \param WidgetParent ƥåȤؤΥݥ󥿡
   //! \param cName å̾Ρ
-  WVoxTrack(const CTrackInf& TrackInf, 
+  WVoxTrack(const CTrackInf& trackInf, 
             QWidget*         WidgetParent=0,
             const char*      cName=0);
   //! \brief 󥹥ȥ饯
@@ -72,7 +83,7 @@ public:
             QWidget*        WidgetParent=0, 
             const char*     cName=0);
   //! \brief ǥȥ饯
-  ~WVoxTrack();
+  virtual ~WVoxTrack();
 
   //! \brief ȥå̾Τ롣
   QString   name() const;
@@ -85,7 +96,7 @@ public:
   int       level() const;
   //! \brief ꤵƤΥѥ롣
   //! 0100ϰϡ
-  int       pan() const;  
+  int       pan() const;
   //! \brief ϸΥե̾Τ롣
   QString   fileName() const;
   //! \brief ϰ֤֤
@@ -119,15 +130,6 @@ public:
   //! \brief ե̾Τꤹ롣
   //! \param strFileName ե̾Ρ
   void      setFileName(const QString& strFileName);
-  //! \brief ֤ꤹ롣
-  //! \param TimeStartPositionArg ()
-  void      setStartPosition(const QTime& TimeStartPositionArg);
-  //! \brief եåȤꤹ롣
-  //! \param TimeOffsetArg եå()
-  void      setOffset(const QTime& TimeOffsetArg);
-  //! \brief ֤ꤹ롣
-  //! \param TimeLengthArg ()
-  void      setLength(const QTime& TimeLengthArg);
   //! \brief ߥ塼Ȥꤹ롣
   //! \param bMute ߥ塼Ȥξ硢true
   void      setMute(bool bMute);
@@ -135,12 +137,16 @@ public:
   //! \param bRecPort 쥳ǥ󥰥ȥåξ硢true
   void      setRec(bool bRecPort);
   //! \brief ȥåξ֤CTrackInfꤹ롣
-  //! \param TrackInfSet ꤵȥå
-  void      setStateByTrackInf(const CTrackInf& TrackInfSet);
+  //! \param trackInfSet ꤵȥå
+  void      setStateByTrackInf(const CTrackInf& trackInfSet);
   //! \brief  ȥåξ֤DOMꤹ롣
   //! \param  nodTrack DOMΡɡ
   void      setStateByDom(const QDomNode& nodTrack);
 
+  //! \brief  ȥå򥹥뤹롣
+  //! \param  x Xɸ
+  void      scrollLocator(int x);
+
   //! ߥ塼ȥȥܥ
   static unsigned int Mute;
   //! Ͽȥܥ
@@ -169,11 +175,11 @@ private:
   //! 쥳ǥ󥰥ǥХ
   QString strOutputDevice;
   //! ϰ֡
-  QTime TimeStartPosition;
+  QTime timeStartPosition;
   //! եåȡ
-  QTime TimeOffset;
+  QTime timeOffset;
   //! ֡
-  QTime TimeLength;
+  QTime timeLength;
 
   //! ¦Υ١åȡ
   QVBox         *VBoxController;
@@ -201,6 +207,8 @@ private:
   QPushButton   *PushButtonMute;
   //! 쥳ǥ󥰤ON/OFFꤹܥ
   QPushButton   *PushButtonRec;
+  //! ɥ
+  WSoundLocator *Locator;
   //! ݥåץåץ˥塼
   QPopupMenu    *PopupMenu;
   //! ˥塼ID()
@@ -231,7 +239,17 @@ public slots:
   //! \param bEnabled  ꤵ줿åȤͭˤ硢trueꡣ
   void slotSetEnabledWidgets(unsigned int unWidgets, bool bEnabled);
 
+  //! \brief ϰ֤ꤹ롣
+  void slotSetStartPosition(const QTime& time);
+  //! \brief եåȤꤹ롣
+  void slotSetOffset(const QTime& time);
+  //! \brief ֤ꤹ롣
+  void slotSetLength(const QTime& time);
+  
 private slots:
+  //! \brief ե̾ѹΥåȡ
+  void slotChangedFileName(const QString& strFileName);
+
   //! \brief ץ쥤ХåǥХѹ׵Υåȡ
   void slotChangePlaybackDevice();
   //! \brief 쥳ǥ󥰥ǥХѹ׵Υåȡ
@@ -249,29 +267,35 @@ private slots:
   //! \brief ѹ׵Υåȡ
   void slotChangeLength();
 
+  //! ѡ
+  void slotMovedContents(int x);
+
 signals:
-  //! \brief ץ쥤ХåǥХѹΥ٥ȡ
+  //! \brief ץ쥤ХåǥХѹΥʥ롣
   void playbackDeviceChanged(const QString&);
-  //! \brief 쥳ǥ󥰥ǥХѹΥ٥ȡ
+  //! \brief 쥳ǥ󥰥ǥХѹΥʥ롣
   void recordingDeviceChanged(const QString&);
-  //! \brief Υ٥ȡ
+  //! \brief Υʥ롣
   void removed();
-  //! \brief ե̾ѹΥ٥ȡ
+  //! \brief ե̾ѹΥʥ롣
   void fileNameChanged(const QString&);
-  //! \brief ٥ѹΥ٥ȡ
+  //! \brief ٥ѹΥʥ롣
   void levelChanged(int);
-  //! \brief ѥѹΥ٥ȡ
+  //! \brief ѥѹΥʥ롣
   void panChanged(int);
-  //! \brief ߥ塼Ⱦ֤ѹ줿Υ٥ȡ
+  //! \brief ߥ塼Ⱦ֤ѹ줿Υʥ롣
   void muteToggled(bool);
-  //! \brief Ͽ֤ѹ줿Υ٥ȡ
+  //! \brief Ͽ֤ѹ줿Υʥ롣
   void recToggled(bool);
-  //! \brief ϰ֤ѹ줿Υ٥ȡ
+  //! \brief ϰ֤ѹ줿Υʥ롣
   void startPositionChanged(const QTime&);
-  //! \brief Ͽ֤ѹ줿Υ٥ȡ
+  //! \brief Ͽ֤ѹ줿Υʥ롣
   void offsetChanged(const QTime&);
-  //! \brief Ͽ֤ѹ줿Υ٥ȡ
+  //! \brief Ͽ֤ѹ줿Υʥ롣
   void lengthChanged(const QTime&);
+
+  //! \brief 뤵줿ȯ륷ʥ롣
+  void locatorScrolled(QObject* ObjectSender, int);
 };
 
 #endif
